@@ -1,5 +1,4 @@
 import * as React from 'react';
-// eslint-disable-next-line no-unused-vars
 import { shallow, ShallowWrapper } from 'enzyme';
 
 import { TextFilter, ListPageWrapper_, FireMan_, MultiListPage } from '../../../public/components/factory/list-page';
@@ -25,7 +24,6 @@ describe(TextFilter.displayName, () => {
     expect(input.props().type).toEqual('text');
     expect(input.props().placeholder).toEqual(`Filter ${label}...`);
     expect(input.props().onChange).toEqual(onChange);
-    expect(input.props().autoFocus).toEqual(true);
     expect(input.props().defaultValue).toEqual(defaultValue);
   });
 });
@@ -34,7 +32,7 @@ describe(FireMan_.displayName, () => {
   let wrapper: ShallowWrapper<any>;
 
   beforeEach(() => {
-    const resources = [{kind: 'nodes'}];
+    const resources = [{kind: 'Node'}];
     wrapper = shallow(<FireMan_.WrappedComponent resources={resources} />);
   });
 
@@ -53,7 +51,7 @@ describe(FireMan_.displayName, () => {
     const createProps = {foo: 'bar'};
     const button = wrapper.setProps({canCreate: true, createProps, createButtonText: 'Create Me!'}).find('#yaml-create');
 
-    expect(wrapper.find('#yaml-create').text()).toEqual('Create Me!');
+    expect(wrapper.find('#yaml-create').childAt(0).text()).toEqual('Create Me!');
 
     Object.keys(createProps).forEach((key) => {
       expect(createProps[key] === button.props()[key]).toBe(true);
@@ -115,7 +113,7 @@ describe(MultiListPage.displayName, () => {
   const ListComponent = () => <div />;
   const wrapper: ShallowWrapper = shallow(<MultiListPage ListComponent={ListComponent} resources={[{
     kind: 'Pod',
-    filterLabel: 'Pods by name',
+    filterLabel: 'by name',
   }]} />);
 
   it('renders a `Firehose` wrapped `ListPageWrapper_`', () => {
