@@ -5,7 +5,8 @@ import { k8sCreate, referenceFor } from '../../module/k8s';
 import { NamespaceModel, ProjectRequestModel, NetworkPolicyModel } from '../../models';
 import { createModalLauncher, ModalTitle, ModalBody, ModalSubmitFooter } from '../factory/modal';
 import { Dropdown, history, PromiseComponent, resourceObjPath, SelectorInput } from '../utils';
-import { FLAGS, setFlag } from '../../features';
+import { setFlag } from '../../actions/features';
+import { FLAGS } from '../../const';
 
 const allow = 'allow';
 const deny = 'deny';
@@ -69,7 +70,7 @@ const CreateNamespaceModal = connect(null, mapDispatchToProps)(class CreateNames
 
   _submit(event) {
     event.preventDefault();
-    const { createProject, close } = this.props;
+    const { createProject, close, onSubmit } = this.props;
 
     let promise = createProject ? this.createProject() : this.createNamespace();
     if (this.state.np === deny) {
@@ -82,9 +83,8 @@ const CreateNamespaceModal = connect(null, mapDispatchToProps)(class CreateNames
 
     this.handlePromise(promise).then(obj => {
       close();
-      if (createProject) {
-        // Redirect to the overview instead of the project details page.
-        history.push(`/overview/ns/${obj.metadata.name}`);
+      if (onSubmit) {
+        onSubmit(obj);
       } else {
         history.push(resourceObjPath(obj, referenceFor(obj)));
       }
@@ -98,7 +98,7 @@ const CreateNamespaceModal = connect(null, mapDispatchToProps)(class CreateNames
   render() {
     const label = this.props.createProject ? 'Project' : 'Namespace';
     const defaultNetworkPolicies = {
-      [allow]: 'No restrictions (default)',
+      [allow]: 'No restrictions',
       [deny]: 'Deny all inbound traffic',
     };
     return <form onSubmit={this._submit.bind(this)} name="form" className="modal-content modal-content--no-inner-scroll co-p-new-user-modal">
@@ -107,19 +107,19 @@ const CreateNamespaceModal = connect(null, mapDispatchToProps)(class CreateNames
         <div className="form-group">
           <label htmlFor="input-name" className="control-label co-required">Name</label>
           <div className="modal-body__field">
-            <input id="input-name" name="name" type="text" className="form-control" onChange={this.handleChange} value={this.state.name || ''} autoFocus required />
+            <input id="input-name" name="name" type="text" className="pf-c-form-control" onChange={this.handleChange} value={this.state.name || ''} autoFocus required />
           </div>
         </div>
         {this.props.createProject && <div className="form-group">
           <label htmlFor="input-display-name" className="control-label">Display Name</label>
           <div className="modal-body__field">
-            <input id="input-display-name" name="displayName" type="text" className="form-control" onChange={this.handleChange} value={this.state.displayName || ''} />
+            <input id="input-display-name" name="displayName" type="text" className="pf-c-form-control" onChange={this.handleChange} value={this.state.displayName || ''} />
           </div>
         </div>}
         {this.props.createProject && <div className="form-group">
           <label htmlFor="input-description" className="control-label">Description</label>
           <div className="modal-body__field">
-            <textarea id="input-description" name="description" className="form-control" onChange={this.handleChange} value={this.state.description || ''} />
+            <textarea id="input-description" name="description" className="pf-c-form-control" onChange={this.handleChange} value={this.state.description || ''} />
           </div>
         </div>}
         {!this.props.createProject && <div className="form-group">
