@@ -1,37 +1,54 @@
 import * as React from 'react';
+import {
+  CloseIcon,
+  DownloadIcon,
+  InfoCircleIcon,
+  PasteIcon,
+} from '@patternfly/react-icons';
 
 import { resourceSidebars } from './resource-sidebars';
 
+export const sidebarScrollTop = () => {
+  document.getElementsByClassName('co-p-has-sidebar__sidebar')[0].scrollTop = 0;
+};
+
 export class ResourceSidebarWrapper extends React.Component {
   constructor(props) {
     super(props);
+    this.toggleSidebar = this.toggleSidebar.bind(this);
     this.state = {
-      showSidebar: true,
+      showSidebar: !props.startHidden,
     };
   }
 
+  toggleSidebar() {
+    this.setState(state => {
+      return {showSidebar: !state.showSidebar};
+    }, () => window.dispatchEvent(new Event('sidebar_toggle')));
+  }
+
   render() {
-    const {style, label} = this.props;
+    const {style, label, linkLabel, children} = this.props;
     const {height} = style;
     const {showSidebar} = this.state;
 
     if (!showSidebar) {
-      return <div className="co-p-has-sidebar__sidebar--hidden hidden-sm">
-        <button className="btn btn-link" onClick={() => this.setState({showSidebar: !showSidebar})}>
-          <span className="fa fa-fw fa-info-circle co-p-has-sidebar__sidebar-link-icon"></span>View samples
+      return <div className="co-p-has-sidebar__sidebar--hidden hidden-sm hidden-xs">
+        <button className="btn btn-link" onClick={this.toggleSidebar}>
+          <InfoCircleIcon className="co-icon-space-r co-p-has-sidebar__sidebar-link-icon" />{linkLabel}
         </button>
       </div>;
     }
 
-    return <div className="co-p-has-sidebar__sidebar co-p-has-sidebar__sidebar--bordered hidden-sm" style={{height}}>
+    return <div className="co-p-has-sidebar__sidebar co-p-has-sidebar__sidebar--bordered hidden-sm hidden-xs" style={{height}}>
       <div className="co-m-pane__body">
-        <button type="button" className="close" aria-hidden="true" aria-label="Close" onClick={() => this.setState({showSidebar: !showSidebar})}>
-          <span className="pficon pficon-close"></span>
+        <button type="button" className="close" aria-label="Close" onClick={this.toggleSidebar}>
+          <CloseIcon />
         </button>
         <h1 className="co-p-has-sidebar__sidebar-heading co-resource-sidebar-header text-capitalize">
-          {label} samples
+          {label}
         </h1>
-        { this.props.children }
+        {children}
       </div>
     </div>;
   }
@@ -48,10 +65,10 @@ export const SampleYaml = ({sample, loadSampleYaml, downloadSampleYaml}) => {
       {details}
     </p>
     <button className="btn btn-link" onClick={() => loadSampleYaml(templateName, kind)}>
-      <span className="fa fa-fw fa-paste" aria-hidden="true"></span> Try it
+      <PasteIcon className="co-icon-space-r" />Try it
     </button>
     <button className="btn btn-link pull-right" onClick={() => downloadSampleYaml(templateName, kind)}>
-      <span className="fa fa-fw fa-download" aria-hidden="true"></span> Download YAML
+      <DownloadIcon className="co-icon-space-r" />Download YAML
     </button>
   </li>;
 };
@@ -65,7 +82,7 @@ export const ResourceSidebar = props => {
   const {kind, label} = kindObj;
   const SidebarComponent = resourceSidebars.get(kind);
   if (SidebarComponent) {
-    return <ResourceSidebarWrapper label={label} style={{height}}>
+    return <ResourceSidebarWrapper label={`${label} Samples`} linkLabel="View Samples" style={{height}}>
       <SidebarComponent {...props} />
     </ResourceSidebarWrapper>;
   }
