@@ -3,6 +3,7 @@ import * as React from 'react';
 import * as PropTypes from 'prop-types';
 import { pluralize } from './';
 import { STREAM_EOF, STREAM_PAUSED, STREAM_ACTIVE } from './resource-log';
+import { OutlinedPlayCircleIcon } from '@patternfly/react-icons';
 
 // Subtracted from log window height to prevent scroll bar from appearing when resume button is shown.
 // Added fullscreen fudge factor to account for fullscreen taking log contents outside of .co-m-pane__body div
@@ -130,7 +131,7 @@ export class LogWindow extends React.PureComponent {
       </div>
       { status === STREAM_PAUSED &&
         <button onClick={this._unpause} className="btn btn-block log-window__resume-btn">
-          <span className="fa fa-play-circle-o" aria-hidden="true"></span>
+          <OutlinedPlayCircleIcon />
           {resumeText}
         </button> }
     </div>;
